savedcmd_arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dtb := gcc -E -Wp,-MMD,arch/arm/boot/dts/nvidia/.tegra20-asus-tf101.dtb.d.pre.tmp -nostdinc -I./scripts/dtc/include-prefixes -undef -D__DTS__ -x assembler-with-cpp -o arch/arm/boot/dts/nvidia/.tegra20-asus-tf101.dtb.dts.tmp arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dts ; ./scripts/dtc/dtc -o arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dtb -b 0 -iarch/arm/boot/dts/nvidia/ -i./scripts/dtc/include-prefixes -Wno-interrupt_provider -Wno-unique_unit_address -Wno-unit_address_vs_reg -Wno-avoid_unnecessary_addr_size -Wno-alias_paths -Wno-graph_child_address -Wno-simple_bus_reg   -d arch/arm/boot/dts/nvidia/.tegra20-asus-tf101.dtb.d.dtc.tmp arch/arm/boot/dts/nvidia/.tegra20-asus-tf101.dtb.dts.tmp ; cat arch/arm/boot/dts/nvidia/.tegra20-asus-tf101.dtb.d.pre.tmp arch/arm/boot/dts/nvidia/.tegra20-asus-tf101.dtb.d.dtc.tmp > arch/arm/boot/dts/nvidia/.tegra20-asus-tf101.dtb.d

source_arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dtb := arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dts

deps_arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dtb := \
  scripts/dtc/include-prefixes/dt-bindings/input/atmel-maxtouch.h \
  scripts/dtc/include-prefixes/dt-bindings/input/gpio-keys.h \
  scripts/dtc/include-prefixes/dt-bindings/input/input.h \
  scripts/dtc/include-prefixes/dt-bindings/input/linux-event-codes.h \
  scripts/dtc/include-prefixes/dt-bindings/thermal/thermal.h \
  arch/arm/boot/dts/nvidia/tegra20.dtsi \
  scripts/dtc/include-prefixes/dt-bindings/clock/tegra20-car.h \
  scripts/dtc/include-prefixes/dt-bindings/gpio/tegra-gpio.h \
  scripts/dtc/include-prefixes/dt-bindings/gpio/gpio.h \
  scripts/dtc/include-prefixes/dt-bindings/memory/tegra20-mc.h \
  scripts/dtc/include-prefixes/dt-bindings/pinctrl/pinctrl-tegra.h \
  scripts/dtc/include-prefixes/dt-bindings/interrupt-controller/arm-gic.h \
  scripts/dtc/include-prefixes/dt-bindings/interrupt-controller/irq.h \
  scripts/dtc/include-prefixes/dt-bindings/soc/tegra-pmc.h \
  arch/arm/boot/dts/nvidia/tegra20-peripherals-opp.dtsi \
  arch/arm/boot/dts/nvidia/tegra20-cpu-opp.dtsi \
  arch/arm/boot/dts/nvidia/tegra20-cpu-opp-microvolt.dtsi \

arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dtb: $(deps_arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dtb)

$(deps_arch/arm/boot/dts/nvidia/tegra20-asus-tf101.dtb):
